## Purpose

We care about fundamental properties of chemical space and their connection to quantum alchemy for molecules and materials. This repository collects the core algorithms once they are somewhat finalized.

- Library use: This code is meant to be used as a library from other projects and therefore is cleaned up and documented.
- Supported: Unlike the research project repositories (which are frozen in time), we provide bug fixes for this library.
